@@ -30,4 +30,4 @@ def run_main():
         main.main(args)
     except KeyboardInterrupt:
         sys.exit(1)
-run_main()
\ No newline at end of file
+# run_main()
\ No newline at end of file
