@@ -477,17 +477,27 @@ def transform_multiple_assign_code(content):
             for ind_ass, each_assign_list in enumerate(assign_list):
                 # print(">>>>>>ind_ass: ", ind_ass)
                 each_assign_list_str = "\n".join([ast.unparse(e_ass) for e_ass in each_assign_list])
-                line_list =[[e_ass.lineno, e_ass.end_lineno] for e_ass in each_assign_list]
-                # line_list.append([[e_ass.lineno, e_ass.end_lineno] for e_ass in each_assign_list])
+                # each_assign_list_str_list = [ast.unparse(e_ass) for e_ass in each_assign_list]
+                # old_node_content = ast.get_source_segment(content, old_node)
+                each_assign_list_str_list = [ ast.get_source_segment(content, e_ass) for e_ass in each_assign_list]
+
+                line_list = [[(e_ass.lineno,e_ass.col_offset), (e_ass.end_lineno,e_ass.end_col_offset)] for e_ass in each_assign_list]
                 new_code = transform_multiple_assign(each_assign_list)
 
-                # new_file_content = replace_file_content_ass(content, each_assign_list, new_code)
-                # assign_list[ind_ass].append(new_code)
-                # complic_code_me_info_dir_pkl = util.data_root + "complic_code_me_info_dir_pkl/each_idiom_type_all_methods/multi_ass/"  # for_else
-                # util.save_file(complic_code_me_info_dir_pkl, "test"+str(ind_ass), new_file_content, ".txt", "w")
-                # util.save_file(complic_code_me_info_dir_pkl, "test_old"+str(ind_ass), content, ".txt", "w")
 
-                code_pair_list.append([class_name,me_name,each_assign_list_str, new_code,line_list])
+                code_pair_list.append([class_name, me_name, each_assign_list_str_list, [new_code], line_list])
+
+                # line_list =[[e_ass.lineno, e_ass.end_lineno] for e_ass in each_assign_list]
+                # # line_list.append([[e_ass.lineno, e_ass.end_lineno] for e_ass in each_assign_list])
+                # new_code = transform_multiple_assign(each_assign_list)
+                #
+                # # new_file_content = replace_file_content_ass(content, each_assign_list, new_code)
+                # # assign_list[ind_ass].append(new_code)
+                # # complic_code_me_info_dir_pkl = util.data_root + "complic_code_me_info_dir_pkl/each_idiom_type_all_methods/multi_ass/"  # for_else
+                # # util.save_file(complic_code_me_info_dir_pkl, "test"+str(ind_ass), new_file_content, ".txt", "w")
+                # # util.save_file(complic_code_me_info_dir_pkl, "test_old"+str(ind_ass), content, ".txt", "w")
+                #
+                # code_pair_list.append([class_name,me_name,each_assign_list_str_list, [new_code],line_list])
 
         return code_pair_list
 
