@@ -280,8 +280,10 @@ def transform_for_multiple_targets_code(content):
                 # complic_code_me_info_dir_pkl = util.data_root + "complic_code_me_info_dir_pkl/each_idiom_type_all_methods/multi_ass/"  # for_else
                 # util.save_file(complic_code_me_info_dir_pkl, "test"+str(ind_ass), new_file_content, ".txt", "w")
                 # util.save_file(complic_code_me_info_dir_pkl, "test_old"+str(ind_ass), content, ".txt", "w")
-                line_list=[[e[0].lineno,e[0].end_lineno]]
-                code_pair_list.append([class_name,me_name,ast.unparse(e[0]), ast.unparse(e[1]),line_list])
+                old_node_content = ast.get_source_segment(content, e[0])
+
+                line_list=[[(e[0].lineno,e[0].col_offset),(e[0].end_lineno,e[0].end_col_offset)]]
+                code_pair_list.append([class_name,me_name,[old_node_content], [ast.unparse(e[1])],line_list])
 
         return code_pair_list
 
