@@ -19,14 +19,14 @@ from RefactoringIdioms.extract_simp_cmpl_data import ast_util
 from RefactoringIdioms.transform_c_s import transform_var_unpack_call_compli_to_simple
 import traceback
 
-def whether_add_end(slice_list, each_seq, arg_seq,step,new_arg_same_list, beg, end):
+def whether_add_end(slice_list, each_seq, arg_seq,step,new_arg_same_list, beg, end,call_node):
     if end == len(slice_list[1:]) and end > beg and step:
         new_arg_same_list.append(
-            [each_seq[beg:end + 1], arg_seq[1][beg:end + 1], arg_seq[2], step]) # arg_list, ind_list, call node, step
-def whether_add(each_seq, arg_seq,step,new_arg_same_list, beg, end):
+            [each_seq[beg:end + 1], arg_seq[1][beg:end + 1], arg_seq[2], step,call_node]) # arg_list, ind_list, call node, step
+def whether_add(each_seq, arg_seq,step,new_arg_same_list, beg, end,call_node):
     if end > beg and step:
         new_arg_same_list.append(
-            [each_seq[beg:end + 1], arg_seq[1][beg:end + 1], arg_seq[2], step])
+            [each_seq[beg:end + 1], arg_seq[1][beg:end + 1], arg_seq[2], step,call_node])
 def get_func_call_by_args(tree):
     code_list = []
     arg_same_list=[]
@@ -92,6 +92,7 @@ def get_func_call_by_args(tree):
     for arg_seq in arg_same_list:
         # print("each_arg: ",arg_seq)
         each_seq=arg_seq[0]
+        call_node=arg_seq[-1]
         #print(each_seq)
         slice_list=[]
         for e_child in ast.walk(tree):
@@ -147,14 +148,14 @@ def get_func_call_by_args(tree):
                         # step=int(e_str)-int(pre_var_str)
 
                         if not step.isdigit() or (step.isdigit() and int(step)==0):
-                            whether_add(each_seq, arg_seq, step, new_arg_same_list, beg, end)
+                            whether_add(each_seq, arg_seq, step, new_arg_same_list, beg, end,call_node)
                             step=None
                             end += 1
                             beg=end
                         else:
                             step=int(step)
                             end+=1
-                            whether_add_end(slice_list, each_seq, arg_seq, step, new_arg_same_list, beg, end)
+                            whether_add_end(slice_list, each_seq, arg_seq, step, new_arg_same_list, beg, end,call_node)
 
                     else:
                         # new_step=int(e_str)-int(pre_var_str)
@@ -166,10 +167,10 @@ def get_func_call_by_args(tree):
                         # print("new_step: ", new_step, ast.unparse(e_node), ast.unparse(pre_var))
                         if new_step.isdigit() and int(new_step)==step:
                             end+=1
-                            whether_add_end(slice_list, each_seq, arg_seq, step, new_arg_same_list, beg, end)
+                            whether_add_end(slice_list, each_seq, arg_seq, step, new_arg_same_list, beg, end,call_node)
                         else:
 
-                            whether_add(each_seq, arg_seq, step, new_arg_same_list, beg, end)
+                            whether_add(each_seq, arg_seq, step, new_arg_same_list, beg, end,call_node)
                             step=None
                             end+=1
                             beg = end
@@ -249,8 +250,18 @@ def transform_star_call_code(content):
                     star_node = transform_var_unpack_call_compli_to_simple.transform_var_unpack_call_each_args(
                         copy_arg_info_list)
                     arg_str_list = [ast.unparse(arg) for arg in arg_info_list[0]]
-                    line_list=[[arg_info_list[0][0].lineno,arg_info_list[0][0].end_lineno]]
-                    code_pair_list.append([class_name,me_name,",".join(arg_str_list), ast.unparse(star_node),line_list])
+                    call_star=arg_info_list[-1]
+                    call_star_start=call_star.col_offset
+                    part_code=ast.get_source_segment(content,call_star)
+                    # print("part_code: ", part_code)
+                    arg_str=part_code[arg_info_list[0][0].col_offset-call_star_start:arg_info_list[0][-1].end_col_offset-call_star_start]
+
+                    line_list = [[(arg_info_list[0][0].lineno,arg_info_list[0][0].col_offset), (arg_info_list[0][-1].end_lineno,arg_info_list[0][-1].end_col_offset)]]
+                    code_pair_list.append(
+                        [class_name, me_name, [arg_str], [ast.unparse(star_node)], line_list])
+
+                    # line_list=[[arg_info_list[0][0].lineno,arg_info_list[0][0].end_lineno]]
+                    # code_pair_list.append([class_name,me_name,",".join(arg_str_list), ast.unparse(star_node),line_list])
 
 
         return code_pair_list
