@@ -232,9 +232,11 @@ def get_chain_compare(content):
             check_chained_comparison(tree, new_code_list)
 
             for old_node,new_node in new_code_list:
-                line_list=[[old_node.lineno, old_node.end_lineno]]
+                old_node_content = ast.get_source_segment(content, old_node)
 
-                code_pair_list.append([class_name,me_name,ast.unparse(old_node),ast.unparse(new_node),line_list])
+                line_list=[[(old_node.lineno,old_node.col_offset), (old_node.end_lineno,old_node.end_col_offset)]]
+
+                code_pair_list.append([class_name,me_name,[old_node_content],[ast.unparse(new_node)],line_list])
         return code_pair_list
 
     except:
