@@ -604,10 +604,27 @@ def transform_for_else_code(content):
                 # util.save_file(complic_code_me_info_dir_pkl, "test"+str(ind_ass), new_file_content, ".txt", "w")
                 # util.save_file(complic_code_me_info_dir_pkl, "test_old"+str(ind_ass), content, ".txt", "w")
             for code in new_code_list:
-                line_list=[[code[5].lineno, code[5].end_lineno]]
-                line_list.append([code[3].lineno, code[3].end_lineno])
-                line_list.append([code[6].lineno, code[6].end_lineno])
-                code_pair_list.append([class_name,me_name,ast.unparse(code[5])+"\n"+ast.unparse(code[3])+"\n"+ast.unparse(code[6]),  ast.unparse(code[4]) if code[7] else ast.unparse(code[5])+"\n"+ast.unparse(code[4]),line_list])
+                old_code_5_content = ast.get_source_segment(content, code[5])
+                old_code_3_content = ast.get_source_segment(content, code[3])
+                old_code_6_content = ast.get_source_segment(content, code[6])
+                if code[7]:
+                    line_list=[[(code[5].lineno,code[5].col_offset), (code[5].end_lineno,code[5].end_col_offset)]]
+                    line_list.append([(code[3].lineno,code[3].col_offset), (code[3].end_lineno,code[3].end_col_offset)])
+                    line_list.append([(code[6].lineno,code[6].col_offset), (code[6].end_lineno,code[6].end_col_offset)])
+
+
+                    code_pair_list.append([class_name,me_name,[old_code_5_content,old_code_3_content,old_code_6_content],  ['',ast.unparse(code[4]),''],line_list])
+                else:
+                    line_list = []
+                    line_list.append(
+                        [(code[3].lineno, code[3].col_offset), (code[3].end_lineno, code[3].end_col_offset)])
+                    line_list.append(
+                        [(code[6].lineno, code[6].col_offset), (code[6].end_lineno, code[6].end_col_offset)])
+                    code_pair_list.append([class_name,me_name,[old_code_3_content,old_code_6_content], [ast.unparse(code[5]),ast.unparse(code[4])],line_list])
+                # code_pair_list.append([class_name, me_name,
+                #                        ast.unparse(code[5]) + "\n" + ast.unparse(code[3]) + "\n" + ast.unparse(code[6]),
+                #                        ast.unparse(code[4]) if code[7] else ast.unparse(code[5]) + "\n" + ast.unparse(
+                #                            code[4]), line_list])
 
         return code_pair_list
 
